@@ -28,8 +28,8 @@ from beartype._check.checkmagic import (
     CODE_PITH_ROOT_NAME_PLACEHOLDER,
     FUNC_CHECKER_NAME_PREFIX,
 )
-from beartype._check.convert.convsanify import sanify_hint_root_statement
-from beartype._check.code.codemake import make_check_expr
+from beartype._check.convert.convmain import sanify_hint_root_statement
+from beartype._check.code.codemain import make_check_expr
 from beartype._check.error.errmain import (
     get_func_pith_violation,
     get_hint_object_violation,
@@ -55,8 +55,8 @@ from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._conf.conftest import die_unless_conf
 from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN_REPR
-from beartype._data.hint.datahintpep import Hint
-from beartype._data.hint.datahinttyping import (
+from beartype._data.typing.datatypingport import Hint
+from beartype._data.typing.datatyping import (
     CallableRaiser,
     CallableRaiserOrTester,
     CallableTester,
@@ -228,7 +228,7 @@ def make_code_raiser_hint_object_check(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
 
     See Also
     --------
@@ -334,7 +334,7 @@ def make_code_tester_check(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
 
     See Also
     --------
@@ -413,7 +413,7 @@ def make_code_raiser_func_pith_check(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
 
     See Also
     --------
@@ -501,7 +501,7 @@ def make_code_raiser_func_pep484_noreturn_check(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint.
     '''
 
     # Lexical scope to be returned, initialized to the empty dictionary.
@@ -686,7 +686,7 @@ def _make_func_checker(
             #  introspect up the call stack for the first stack frame residing
             #  in a non-"beartype" module, which these objects then resolve each
             #  relative forward reference against.
-            #* Consider refactoring our "codemake" algorthm to unconditionally
+            #* Consider refactoring our "codemain" algorthm to unconditionally
             #  do this for *ALL* relative forward references. Doing so would
             #  (probably) be a lot faster than the current global string
             #  replacement approach... maybe. Okay, maybe not. But maybe.
@@ -703,7 +703,7 @@ def _make_func_checker(
             #statement-level type-checkers actually do run in the same scopes
             #that their type hints are defined in. Huh. Pretty nifty, eh? This
             #then suggests that:
-            #* We'll need to generalize our "codemake" function to accept a new
+            #* We'll need to generalize our "codemain" function to accept a new
             #  optional "is_refs_relative_proxy: bool = False" parameter. When:
             #  * "True", code generation replaces all relative forward
             #    references with corresponding "ForwardRefRelativeProxy" objects
@@ -778,14 +778,7 @@ def _make_func_checker(
                 func_name=func_checker_name,
                 func_code=func_checker_code,
                 func_locals=func_scope,
-
-                #FIXME: Almost right but *NOT* quite right. Why? Because
-                #make_func() will append a space to "func_label", but
-                #"EXCEPTION_PLACEHOLDER" is *ALREADY* suffixed by a space. Oh,
-                #well. It's not a super-big deal. In theory, this function
-                #should *NEVER* raise exceptions, anyway. *shrug*
                 func_label=EXCEPTION_PLACEHOLDER,
-
                 is_debug=conf.is_debug,
             )
         # If one or more warnings were issued, reissue these warnings with each
@@ -854,7 +847,7 @@ def _make_code_raiser_violation(
     CodeGenerated
         Tuple containing the Python code snippet dynamically generated by this
         code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint for
+        :attr:`beartype._data.typing.datatyping.CodeGenerated` type hint for
         details.
 
     Raises
