@@ -14,7 +14,7 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype._check.checkmagic import VAR_NAME_RANDOM_INT
-from beartype._data.hint.datahinttyping import CallableStrFormat
+from beartype._data.typing.datatyping import CallableStrFormat
 
 # ....................{ CODE ~ container : (reiterable|seq)}....................
 CODE_PEP484585_REITERABLE_OR_SEQUENCE = '''(
