@@ -22,22 +22,21 @@ from beartype._data.cls.datacls import (
     TYPE_BUILTIN_NAME_TO_TYPE,
     TYPES_PEP484585_REF,
 )
-from beartype._data.hint.datahinttyping import (
+from beartype._data.typing.datatyping import (
     Pep484585ForwardRef,
     TypeException,
     TypeStack,
 )
-from beartype._data.api.standard.datamodpy import BUILTINS_MODULE_NAME
+from beartype._data.api.standard.datapy import BUILTINS_MODULE_NAME
 from beartype._util.module.utilmodget import get_object_module_name_or_none
 from beartype._util.module.utilmodtest import is_module
-from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_10
 from beartype._util.text.utiltextlabel import label_callable
 from collections.abc import (
     Callable,
     Sequence,
 )
 
-# ....................{ VALIDATORS                         }....................
+# ....................{ RAISERS                            }....................
 #FIXME: Validate that this forward reference string is *NOT* the empty string.
 #FIXME: Validate that this forward reference string is a syntactically valid
 #"."-delimited concatenation of Python identifiers. We already have logic
@@ -71,12 +70,12 @@ def die_unless_hint_pep484585_ref(
     ----------
     hint : object
         Object to be validated.
-    exception_cls : Type[Exception]
+    exception_cls : Type[Exception], default: BeartypeDecorHintForwardRefException
         Type of exception to be raised in the event of a fatal error. Defaults
         to :exc:`.BeartypeDecorHintForwardRefException`.
-    exception_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        exception message. Defaults to the empty string.
+    exception_prefix : str, default: ''
+        Human-readable substring prefixing raised exception messages. Defaults
+        to the empty string.
 
     Raises
     ------
@@ -209,7 +208,12 @@ def get_hint_pep484585_ref_names(
         # Forward reference classname referred to by this reference.
         hint_name = hint.__forward_arg__
 
-        # If the active Python interpreter targets >= Python 3.10, then this
+        # Fully-qualified name of the module to which this presumably
+        # relative forward reference is relative to if any *OR* "None"
+        # otherwise (i.e., if *NO* such name was passed at forward reference
+        # instantiation time).
+        #
+        # Since the active Python interpreter targets >= Python 3.10, this
         # "typing.ForwardRef" object defines an optional "__forward_module__:
         # Optional[str] = None" dunder attribute whose value is either:
         # * If Python passed the "module" parameter when instantiating this
@@ -231,16 +235,7 @@ def get_hint_pep484585_ref_names(
         #   of the Python 3.9 development cycle do *NOT* support this. This is
         #   currently only safely usable under Python >= 3.10 -- all patch
         #   releases of which are known to define this dunder attribute.
-        #
-        # In this case...
-        if IS_PYTHON_AT_LEAST_3_10:
-            # Fully-qualified name of the module to which this presumably
-            # relative forward reference is relative to if any *OR* "None"
-            # otherwise (i.e., if *NO* such name was passed at forward reference
-            # instantiation time).
-            hint_module_name = hint.__forward_module__
-        # Else, the active Python interpreter targets < Python 3.9 and thus
-        # fails to define the  "__forward_module__" dunder attribute.
+        hint_module_name = hint.__forward_module__
 
     # Return metadata describing this forward reference relative to this module.
     return hint_module_name, hint_name
