@@ -13,22 +13,34 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ TODO                               }....................
+#FIXME: Conditionally emit a non-fatal PEP 563-specific warning when the active
+#Python interpreter targets Python >= 3.10 *AND* the passed callable is nested.
+#FIXME: Actually, don't even bother. Instead, generalize the resolve_pep563()
+#function defined below to emit a non-fatal deprecation warning when Python 3.13
+#reaches its End-of-Life on October, 2029. At that point, PEP 563 will be
+#officially deprecated. Two minor CPython releases after that happens, the
+#entire "from __future__ import annotations" pragma and thus PEP 563 itself will
+#be officially *REMOVED* from the language specification. At that point, any
+#attempt by end users to use "from __future__ import annotations" will raise a
+#fatal "SyntaxError" from CPython itself. \o/
+
 #FIXME: [DOCOS] Officially document both this and the public "beartype.peps"
 #submodule, please.
 
-#FIXME: Conditionally emit a non-fatal PEP 563-specific warning when the active
-#Python interpreter targets Python >= 3.10 *AND* the passed callable is nested.
-
 # ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypePep563Exception
-from beartype._check.metadata.metadecor import make_beartype_call
 from beartype._check.forward.fwdresolve import resolve_hint
-from beartype._conf.confmain import BeartypeConf
+from beartype._check.metadata.metadecor import (
+    cull_beartype_call,
+    make_beartype_call,
+)
 from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
-from beartype._data.hint.datahinttyping import TypeStack
-from beartype._util.cache.pool.utilcachepoolinstance import (
-    release_instance)
-from beartype._util.func.utilfuncget import get_func_annotations
+from beartype._conf.confmain import BeartypeConf
+from beartype._data.typing.datatyping import TypeStack
+from beartype._util.hint.pep.proposal.pep649 import (
+    get_pep649_hintable_annotations,
+    set_pep649_hintable_annotations,
+)
 from collections.abc import Callable
 
 # ....................{ RESOLVERS                          }....................
@@ -150,19 +162,11 @@ def resolve_pep563(
     # parameter and return of the passed callable to the non-string type hint
     # resolved from the string type hint annotating that parameter or return --
     # raising an exception if that callable is *NOT* a pure-Python callable.
-    #
-    # Note that the "func.__annotations__" dictionary *CANNOT* be safely
-    # directly assigned to below, as the loop performing that assignment below
-    # necessarily iterates over that dictionary. As with most languages, Python
-    # containers cannot be safely mutated while being iterated.
-    arg_name_to_hint = get_func_annotations(
-        func=func,
-        exception_cls=BeartypePep563Exception,
-        exception_prefix='Callable ',
-    )
+    func_annotations = get_pep649_hintable_annotations(
+        hintable=func, exception_cls=BeartypePep563Exception)
 
     # If that callable is unannotated, silently reduce to a noop.
-    if not arg_name_to_hint:
+    if not func_annotations:
         return
     # Else, that callable is annotated by one or more type hints.
 
@@ -199,7 +203,7 @@ def resolve_pep563(
     #
     # For the name of each annotated parameter and return of the passed callable
     # and the type hint annotating that parameter or return...
-    for hint in arg_name_to_hint.values():
+    for hint in func_annotations.values():
         # If this hint is *NOT* stringified, this hint was either:
         # * Never postponed under PEP 563 (i.e., the module defining that
         #   callable did *NOT* import "from __future__ import annotations").
@@ -243,7 +247,7 @@ def resolve_pep563(
     # below, as the loop performing that assignment below necessarily iterates
     # over that dictionary. As with most languages, Python containers cannot be
     # safely mutated while being iterated.
-    arg_name_to_hint = arg_name_to_hint.copy()
+    func_annotations = func_annotations.copy()
 
     # ..................{ RESOLUTION                         }..................
     # For the name of each annotated parameter and return of the passed callable
@@ -256,57 +260,30 @@ def resolve_pep563(
     # * largely pointless (e.g., due to dictionary comprehensions being either
     #   no faster or even slower than explicit iteration for small dictionary
     #   sizes, as "func.__annotations__" usually is).
-    for arg_name, hint in arg_name_to_hint.items():
-        # Resolve this stringified type hint to the non-string type hint to
-        # which this string refers.
-        arg_name_to_hint[arg_name] = resolve_hint(
+    for pith_name, hint in func_annotations.items():
+        # Non-string hint to which this stringified hint refers
+        hint = resolve_hint(
             hint=hint,
             decor_meta=decor_meta,
             exception_cls=BeartypePep563Exception,
         )
 
-    # ..................{ RETURN                             }..................
-    # Release this beartype call metadata back to its object pool.
-    release_instance(decor_meta)
+        # Safely set the hint annotating the parameter or return with the passed
+        # name of the decorated callable to the passed hint in a portable manner
+        # consistent with both PEP 649 and Python >= 3.14.
+        decor_meta.set_func_pith_hint(pith_name=pith_name, hint=hint)
 
-    #FIXME: Shift this logic into a new set_object_annotations() function. Under
-    #Python >= 3.14, this logic is likely to require delicate surgery. *sigh*
-    # Attempt to...
-    try:
-        # Atomically (i.e., all-at-once) replace that callable's postponed
-        # annotations with these resolved annotations for safety and efficiency.
-        #
-        # While the @beartype decorator goes to great lengths to preserve the
-        # originating "__annotations__" dictionary as is, PEP 563 is
-        # sufficiently expensive, non-trivial, and general-purpose to support
-        # that generically resolving postponed annotations for all downstream
-        # third-party callers is justified. Everyone benefits from replacing
-        # useless postponed annotations with useful real annotations; so, do so.
-        func.__annotations__ = arg_name_to_hint
-    # If doing so fails with an exception resembling the following, that
-    # callable is *NOT* a pure-Python callable but rather a C-based decorator
-    # object of some sort (e.g., class, property, or static method descriptor):
-    #     AttributeError: 'method' object has no attribute '__annotations__'
+    # ..................{ RETURN                             }..................
+    # Deinitialize this beartype call metadata.
     #
-    # C-based decorator objects define a read-only "__annotations__" dunder
-    # attribute that proxies an original writeable "__annotations__" dunder
-    # attribute of the pure-Python callables they originally decorated. Ergo,
-    # detecting this edge case is non-trivial and most easily deferred to
-    # this late time. While non-ideal, simplicity >>>> idealism in this case.
-    except AttributeError:
-        # For the name of each annotated parameter and return of that callable
-        # and the destringified type hint annotating this parameter or return,
-        # overwrite the stringified type hint originally annotating this
-        # parameter or return with this destringified type hint.
-        #
-        # Note that:
-        # * The above assignment is an efficient O(1) operation and thus
-        #   intentionally performed first.
-        # * This iteration-based assignment is an inefficient O(n) operation
-        #   (where "n" is the number of annotated parameters and returns of that
-        #   callable) and thus intentionally performed last here.
-        for arg_name, arg_hint in arg_name_to_hint.items():
-            func.__annotations__[arg_name] = arg_hint
+    # Note that this implicitly replaces that callable's postponed hints with
+    # these resolved hints. While the @beartype decorator goes to great lengths
+    # to preserve the originating "__annotations__" dictionary as is, PEP 563 is
+    # sufficiently expensive, non-trivial, and general-purpose to support that
+    # generically resolving postponed annotations for all downstream third-party
+    # callers is justified. Everyone benefits from replacing useless postponed
+    # annotations with useful real annotations; so, do so.
+    cull_beartype_call(decor_meta)
 
     # print(
     #     f'{func.__name__}() PEP 563-postponed annotations resolved:'
