@@ -22,37 +22,38 @@ from pathlib import Path
 
 def DirRelative(parent_dir: Path, relative_dirname: str) -> Path:
     '''
-    Concrete platform-agnostic :mod:`Path` object encapsulating the absolute
-    dirname of a directory relative to the passed :mod:`Path` object
+    Concrete platform-agnostic :class:`.Path` object encapsulating the absolute
+    dirname of a directory relative to the passed :class:`.Path` object
     encapsulating an arbitrary directory if found *or* raise an exception
     otherwise.
 
     Parameters
     ----------
     parent_dir : Path
-        :mod:`Path` encapsulating an arbitrary **parent directory** (i.e.,
+        :class:`.Path` encapsulating an arbitrary **parent directory** (i.e.,
         directory containing the subdirectory to be returned).
     relative_dirname : str
         Relative dirname of this subdirectory relative to this parent
         directory.
 
     Returns
-    ----------
+    -------
     Path
-        :mod:`Path` directory relative to the passed :mod:`Path` directory.
+        :class:`.Path` directory relative to the passed :class:`.Path` directory.
 
     Raises
-    ----------
+    ------
     BeartypeTestPathException
         If this path exists but is either:
 
         * *Not* a directory.
         * A directory *not* satisfying the expected filesystem structure.
-    FileNotFoundError
-        If this path does *not* exist.
-    RuntimeError
-        If this path exists but whose resolution to a physical path requires
-        resolving one or more cyclic symbolic links inducing an infinite loop.
+    OSError
+        If either:
+
+        * This path does *not* exist.
+        * This path exists but whose resolution to a physical path requires
+          resolving one or more cyclic symbolic links inducing an infinite loop.
     '''
     assert isinstance(parent_dir, Path), (
         f'{repr(parent_dir)} not "pathlib.Path" object.')
@@ -64,9 +65,8 @@ def DirRelative(parent_dir: Path, relative_dirname: str) -> Path:
     subdir_unresolved = parent_dir / relative_dirname
 
     # Canonicalize this relative dirname into an absolute dirname if this path
-    # exists *OR* raise a "FileNotFoundError" or "RuntimeError" exception
-    # otherwise.
-    subdir = subdir_unresolved.resolve()
+    # exists *OR* raise an "OSError" exception.
+    subdir = subdir_unresolved.resolve(strict=True)
 
     # If this path is *NOT* a directory, raise an exception.
     if not subdir.is_dir():
@@ -79,35 +79,36 @@ def DirRelative(parent_dir: Path, relative_dirname: str) -> Path:
 
 def FileRelative(parent_dir: Path, relative_filename: str) -> Path:
     '''
-    Concrete platform-agnostic :mod:`Path` object encapsulating the absolute
-    filename of a file relative to the passed :mod:`Path` object encapsulating
+    Concrete platform-agnostic :class:`.Path` object encapsulating the absolute
+    filename of a file relative to the passed :class:`.Path` object encapsulating
     an arbitrary directory if found *or* raise an exception otherwise.
 
     Parameters
     ----------
     parent_dir : Path
-        :mod:`Path` encapsulating an arbitrary **parent directory** (i.e.,
+        :class:`.Path` encapsulating an arbitrary **parent directory** (i.e.,
         directory containing the file to be returned).
     relative_filename : str
         Relative filename of this file relative to this parent directory.
 
     Returns
-    ----------
+    -------
     Path
-        :mod:`Path` file relative to the passed :mod:`Path` directory.
+        :class:`.Path` file relative to the passed :class:`.Path` directory.
 
     Raises
-    ----------
+    ------
     BeartypeTestPathException
         If this path exists but is either:
 
         * *Not* a directory.
         * A directory *not* satisfying the expected filesystem structure.
-    FileNotFoundError
-        If this path does *not* exist.
-    RuntimeError
-        If this path exists but whose resolution to a physical path requires
-        resolving one or more cyclic symbolic links inducing an infinite loop.
+    OSError
+        If either:
+
+        * This path does *not* exist.
+        * This path exists but whose resolution to a physical path requires
+          resolving one or more cyclic symbolic links inducing an infinite loop.
     '''
     assert isinstance(parent_dir, Path), (
         f'{repr(parent_dir)} not "pathlib.Path" object.')
@@ -119,9 +120,8 @@ def FileRelative(parent_dir: Path, relative_filename: str) -> Path:
     file_unresolved = parent_dir / relative_filename
 
     # Canonicalize this relative filename into an absolute filename if this
-    # path exists *OR* raise a "FileNotFoundError" or "RuntimeError" exception
-    # otherwise.
-    file = file_unresolved.resolve()
+    # path exists *OR* raise an "OSError" exception.
+    file = file_unresolved.resolve(strict=True)
 
     # If this path is *NOT* a file, raise an exception.
     if not file.is_file():
