@@ -7,7 +7,7 @@
 Beartype **Python expression indentation substring unit tests.**
 
 This submodule unit tests the public API of the public
-:mod:`beartype._data.hint.pep.sign.datapepsignset` submodule.
+:mod:`beartype._data.hint.sign.datahintsignset` submodule.
 '''
 
 # ....................{ IMPORTS                            }....................
