@@ -445,10 +445,8 @@ def test_is_func_wrapper() -> None:
 
     # Defer test-specific imports.
     from beartype._util.func.utilfunctest import is_func_wrapper
-    from beartype_test.a00_unit.data.data_type import (
-        decorator_isomorphic,
-        function,
-    )
+    from beartype_test.a00_unit.data.data_type import function
+    from beartype_test.a00_unit.data.func.data_decor import decorator_isomorphic
 
     # Assert this tester accepts wrappers generated by standard decorators.
     assert is_func_wrapper(decorator_isomorphic(function)) is True
@@ -472,12 +470,14 @@ def test_is_func_wrapper_isomorphic() -> None:
     from beartype._util.func.utilfunctest import is_func_wrapper_isomorphic
     from beartype_test.a00_unit.data.data_type import (
         context_manager_factory,
-        decorator_isomorphic,
-        decorator_nonisomorphic,
         function,
         object_callable_wrapper_isomorphic,
         wrapper_isomorphic,
     )
+    from beartype_test.a00_unit.data.func.data_decor import (
+        decorator_isomorphic,
+        decorator_nonisomorphic,
+    )
 
     # ....................{ PASS                           }....................
     # Assert this tester accepts isomorphic wrapper closures.
