@@ -7,7 +7,7 @@
 **Beartype configuration unit tests.**
 
 This submodule unit tests the subset of the public API of the :mod:`beartype`
-package defined by the private :mod:`beartype._conf.confcls` submodule.
+package defined by the private :mod:`beartype._conf.confmain` submodule.
 '''
 
 # ....................{ IMPORTS                            }....................
@@ -26,10 +26,10 @@ def test_conf_dataclass() -> None:
     # Defer test-specific imports.
     from beartype import (
         BeartypeConf,
-        BeartypeDecorationPosition,
-        BeartypeHintOverrides,
+        BeartypeDecorPlace,
         BeartypeStrategy,
         BeartypeViolationVerbosity,
+        FrozenDict,
     )
     from beartype.roar import (
         BeartypeConfParamException,
@@ -37,13 +37,13 @@ def test_conf_dataclass() -> None:
         BeartypeCallHintReturnViolation,
         BeartypeDoorHintViolation,
     )
-    # from beartype.typing import Union
-    from beartype._conf.confoverrides import (
-        BEARTYPE_HINT_OVERRIDES_EMPTY,
-        beartype_hint_overrides_pep484_tower,
-    )
+    from beartype._conf._confoverrides import _hint_overrides_pep484_tower
+    from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
     from beartype._util.utilobject import get_object_type_basename
-    from pytest import raises
+    from pytest import (
+        raises,
+        warns,
+    )
 
     # ....................{ CLASSES                        }....................
     class FakeBool(object):
@@ -61,15 +61,15 @@ def test_conf_dataclass() -> None:
     # * The unqualified basenames of and all public fields of this class.
     BEAR_CONF_REPR_SUBSTRS = (
         'BeartypeConf',
-        'claw_decoration_position_funcs',
-        'claw_decoration_position_types',
+        'claw_decor_place_func',
+        'claw_decor_place_type',
         'claw_is_pep526',
         'claw_skip_package_names',
         'hint_overrides',
-        'is_check_pep557',
         'is_color',
         'is_debug',
         'is_pep484_tower',
+        'is_pep557_fields',
         'strategy',
         'violation_door_type',
         'violation_param_type',
@@ -84,20 +84,20 @@ def test_conf_dataclass() -> None:
 
     # Non-empty hint overrides mapping one or more arbitrary source type hints
     # to corresponding arbitrary target type hints.
-    BEAR_HINT_OVERRIDES_NONEMPTY = BeartypeHintOverrides({bool: FakeBool})
+    BEAR_HINT_OVERRIDES_NONEMPTY = FrozenDict({bool: FakeBool})
 
     # All possible keyword arguments initialized to non-default values with
     # which to instantiate a non-default beartype configuration.
     BEAR_CONF_NONDEFAULT_KWARGS = dict(
-        claw_decoration_position_funcs=BeartypeDecorationPosition.FIRST,
-        claw_decoration_position_types=BeartypeDecorationPosition.FIRST,
+        claw_decor_place_func=BeartypeDecorPlace.LAST,
+        claw_decor_place_type=BeartypeDecorPlace.FIRST,
         claw_is_pep526=False,
         claw_skip_package_names=('Made_contrast_with', 'the_universe',),
         hint_overrides=BEAR_HINT_OVERRIDES_NONEMPTY,
-        is_check_pep557=True,
         is_color=True,
         is_debug=True,
         is_pep484_tower=True,
+        is_pep557_fields=True,
         strategy=BeartypeStrategy.Ologn,
         violation_door_type=RuntimeError,
         violation_param_type=TypeError,
@@ -131,15 +131,15 @@ def test_conf_dataclass() -> None:
     assert BeartypeConf() is BeartypeConf()
     assert (
         BeartypeConf(
-            claw_decoration_position_funcs=BeartypeDecorationPosition.FIRST,
-            claw_decoration_position_types=BeartypeDecorationPosition.LAST,
+            claw_decor_place_func=BeartypeDecorPlace.LAST,
+            claw_decor_place_type=BeartypeDecorPlace.FIRST,
             claw_is_pep526=False,
             claw_skip_package_names=('Made_contrast_with', 'the_universe',),
             hint_overrides=BEAR_HINT_OVERRIDES_NONEMPTY,
-            is_check_pep557=True,
             is_debug=True,
             is_color=True,
             is_pep484_tower=True,
+            is_pep557_fields=True,
             strategy=BeartypeStrategy.On,
             violation_door_type=RuntimeError,
             violation_param_type=TypeError,
@@ -156,31 +156,31 @@ def test_conf_dataclass() -> None:
             violation_param_type=TypeError,
             violation_door_type=RuntimeError,
             strategy=BeartypeStrategy.On,
+            is_pep557_fields=True,
             is_pep484_tower=True,
             is_color=True,
             is_debug=True,
-            is_check_pep557=True,
             hint_overrides=BEAR_HINT_OVERRIDES_NONEMPTY,
             claw_is_pep526=False,
             claw_skip_package_names=('Made_contrast_with', 'the_universe',),
-            claw_decoration_position_types=BeartypeDecorationPosition.LAST,
-            claw_decoration_position_funcs=BeartypeDecorationPosition.FIRST,
+            claw_decor_place_type=BeartypeDecorPlace.FIRST,
+            claw_decor_place_func=BeartypeDecorPlace.LAST,
         )
     )
 
     # ....................{ PASS ~ properties              }....................
     # Assert that the default configuration contains the expected fields.
-    assert BEAR_CONF_DEFAULT.claw_decoration_position_funcs is (
-        BeartypeDecorationPosition.LAST)
-    assert BEAR_CONF_DEFAULT.claw_decoration_position_types is (
-        BeartypeDecorationPosition.LAST)
+    assert BEAR_CONF_DEFAULT.claw_decor_place_func is (
+        BeartypeDecorPlace.LAST_BEFORE_DECOR_HOSTILE)
+    assert BEAR_CONF_DEFAULT.claw_decor_place_type is (
+        BeartypeDecorPlace.LAST)
     assert BEAR_CONF_DEFAULT.claw_is_pep526 is True
     assert BEAR_CONF_DEFAULT.claw_skip_package_names == ()
-    assert BEAR_CONF_DEFAULT.hint_overrides is BEARTYPE_HINT_OVERRIDES_EMPTY
-    assert BEAR_CONF_DEFAULT.is_check_pep557 is False
+    assert BEAR_CONF_DEFAULT.hint_overrides is FROZENDICT_EMPTY
     assert BEAR_CONF_DEFAULT.is_color is None
     assert BEAR_CONF_DEFAULT.is_debug is False
     assert BEAR_CONF_DEFAULT.is_pep484_tower is False
+    assert BEAR_CONF_DEFAULT.is_pep557_fields is False
     assert BEAR_CONF_DEFAULT.strategy is BeartypeStrategy.O1
     assert BEAR_CONF_DEFAULT.violation_door_type is (
         BeartypeDoorHintViolation)
@@ -195,19 +195,19 @@ def test_conf_dataclass() -> None:
     assert BEAR_CONF_DEFAULT._is_warning_cls_on_decorator_exception_set is False
 
     # Assert that the non-default configuration contains the expected fields.
-    assert BEAR_CONF_DEFAULT.claw_decoration_position_funcs is (
-        BeartypeDecorationPosition.LAST)
-    assert BEAR_CONF_DEFAULT.claw_decoration_position_types is (
-        BeartypeDecorationPosition.LAST)
+    assert BEAR_CONF_NONDEFAULT.claw_decor_place_func is (
+        BeartypeDecorPlace.LAST)
+    assert BEAR_CONF_NONDEFAULT.claw_decor_place_type is (
+        BeartypeDecorPlace.FIRST)
     assert BEAR_CONF_NONDEFAULT.claw_is_pep526 is False
     assert BEAR_CONF_NONDEFAULT.claw_skip_package_names == (
         'Made_contrast_with', 'the_universe',)
     assert BEAR_CONF_NONDEFAULT.hint_overrides == (
-        BEAR_HINT_OVERRIDES_NONEMPTY | beartype_hint_overrides_pep484_tower())
-    assert BEAR_CONF_NONDEFAULT.is_check_pep557 is True
+        BEAR_HINT_OVERRIDES_NONEMPTY | _hint_overrides_pep484_tower())
     assert BEAR_CONF_NONDEFAULT.is_color is True
     assert BEAR_CONF_NONDEFAULT.is_debug is True
     assert BEAR_CONF_NONDEFAULT.is_pep484_tower is True
+    assert BEAR_CONF_NONDEFAULT.is_pep557_fields is True
     assert BEAR_CONF_NONDEFAULT.strategy is BeartypeStrategy.Ologn
     assert BEAR_CONF_NONDEFAULT.violation_door_type is RuntimeError
     assert BEAR_CONF_NONDEFAULT.violation_param_type is TypeError
@@ -291,14 +291,14 @@ def test_conf_dataclass() -> None:
     for bear_conf_repr_substr in BEAR_CONF_REPR_SUBSTRS:
         assert bear_conf_repr_substr in BEAR_CONF_NONDEFAULT_REPR
 
-    # ....................{ FAIL                           }....................
+    # ....................{ FAIL ~ raise                   }....................
     # Assert that instantiating a configuration with an invalid parameter raises
     # the expected exception.
     with raises(BeartypeConfParamException):
-        BeartypeConf(claw_decoration_position_funcs=(
+        BeartypeConf(claw_decor_place_func=(
             "High 'mid the shifting domes of sheeted spray"))
     with raises(BeartypeConfParamException):
-        BeartypeConf(claw_decoration_position_types=(
+        BeartypeConf(claw_decor_place_type=(
             "That canopied his path o'er the waste deep;"))
     with raises(BeartypeConfParamException):
         BeartypeConf(claw_is_pep526=(
@@ -320,9 +320,6 @@ def test_conf_dataclass() -> None:
     with raises(BeartypeConfParamException):
         BeartypeConf(hint_overrides=(
             'Wildered, and wan, and panting, she returned.'))
-    with raises(BeartypeConfParamException):
-        BeartypeConf(is_check_pep557=(
-            "Space region'd with life-air; and barren void;"))
     with raises(BeartypeConfParamException):
         BeartypeConf(is_color=(
             'And many sounds, and much of life and death.'))
@@ -332,6 +329,9 @@ def test_conf_dataclass() -> None:
     with raises(BeartypeConfParamException):
         BeartypeConf(is_pep484_tower=(
             'In the calm darkness of the moonless nights,'))
+    with raises(BeartypeConfParamException):
+        BeartypeConf(is_pep557_fields=(
+            "Space region'd with life-air; and barren void;"))
     with raises(BeartypeConfParamException):
         BeartypeConf(strategy=(
             'By all, but which the wise, and great, and good'))
@@ -370,22 +370,22 @@ def test_conf_dataclass() -> None:
     with raises(BeartypeConfParamException):
         BeartypeConf(
             is_pep484_tower=True,
-            hint_overrides=BeartypeHintOverrides({float: complex})
+            hint_overrides=FrozenDict({float: complex})
         )
     with raises(BeartypeConfParamException):
         BeartypeConf(
             is_pep484_tower=True,
-            hint_overrides=BeartypeHintOverrides({complex: int})
+            hint_overrides=FrozenDict({complex: int})
         )
 
     # Assert that attempting to modify any public read-only property of this
     # dataclass raises the expected exception.
     with raises(AttributeError):
-        BEAR_CONF_DEFAULT.claw_decoration_position_funcs = (
-            BeartypeDecorationPosition.FIRST)
+        BEAR_CONF_DEFAULT.claw_decor_place_func = (
+            BeartypeDecorPlace.FIRST)
     with raises(AttributeError):
-        BEAR_CONF_DEFAULT.claw_decoration_position_types = (
-            BeartypeDecorationPosition.FIRST)
+        BEAR_CONF_DEFAULT.claw_decor_place_type = (
+            BeartypeDecorPlace.FIRST)
     with raises(AttributeError):
         BEAR_CONF_DEFAULT.claw_is_pep526 = True
     with raises(AttributeError):
@@ -414,6 +414,16 @@ def test_conf_dataclass() -> None:
     with raises(AttributeError):
         BEAR_CONF_DEFAULT.warning_cls_on_decorator_exception = None
 
+    # ....................{ FAIL ~ warn                    }....................
+    # Assert that instantiating a configuration with a deprecated parameter
+    # issues the expected warning.
+    with warns(DeprecationWarning):
+        BeartypeConf(claw_decoration_position_funcs=BeartypeDecorPlace.FIRST)
+    with warns(DeprecationWarning):
+        BeartypeConf(claw_decoration_position_types=BeartypeDecorPlace.FIRST)
+    with warns(DeprecationWarning):
+        BeartypeConf(is_check_pep557=True)
+
 # ....................{ TESTS ~ arg                        }....................
 def test_conf_is_color(monkeypatch: 'pytest.MonkeyPatch') -> None:
     '''
