@@ -86,6 +86,7 @@ from beartype.meta import (
     COPYRIGHT,
     NAME,
     SPHINX_THEME_NAME,
+    URL_BLUESKY,
     URL_CONDA,
     URL_LIBRARIES,
     URL_PYPI,
@@ -163,11 +164,12 @@ exclude_patterns = [
 rst_prolog = '''
 .. tip::
 
-   `Feed the bear! The bear is rooting around in your refuse pile <GitHub
-   Sponsors_>`__. You feel sadness.
+   💗 **Upbear us** at `GitHub Sponsors`_ and `SonarQube Advanced Security
+   (Tidelift) <SonarQube Advanced Security_>`__. **Follow us** `on Bluesky
+   <beartype Bluesky_>`__.
+
+   Your generous support is our quality assurance. 💗
 '''
-   # `Feed the bear <GitHub Sponsors_>`__! `Animals wearing jewelry
-   # <beadspace9_>`__! *What is even going on with this banner!?*
 
 # String of arbitrary reStructuredText (reST) to be implicitly appended to the
 # contents of *ALL* reST documents rendered by this configuration, initialized
@@ -524,8 +526,12 @@ python_maximum_signature_line_length = 80
 # ....................{ BUILD ~ html                       }....................
 # Relative filename or URL of a small image (i.e., no wider than 200px) to be
 # rendered in the upper left-hand corner of the sidebar for this theme.
-html_logo = 'https://raw.githubusercontent.com/beartype/beartype-assets/main/badge/bear-ified.svg'
+html_logo = '_static/beartype_logo.svg'
+# html_logo = 'https://raw.githubusercontent.com/beartype/beartype-assets/main/badge/bear-ified.svg'
+# html_logo = 'https://img.shields.io/badge/%F0%9F%91%8C%F0%9F%90%BB-Bear--ified%E2%84%A2-dead80'
+# html_logo = 'https://raw.githubusercontent.com/beartype/beartype-assets/refs/heads/main/badge/bear-ified.svg'
 
+#FIXME: Currently unused. *shrug*
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files;
 # ergo, a file named "default.css" will overwrite the builtin "default.css".
@@ -558,15 +564,17 @@ html_theme_options = {
     #FIXME: Add favicon support here, please. See also:
     #    https://pydata-sphinx-theme.readthedocs.io/en/v0.7.2/user_guide/configuring.html#adding-favicons
 
-    # Announcement banner defined as a string of arbitrary HTML, temporarily
-    # displayed at the top of each page until the user begins scrolling.
-    'announcement': (
-        '<p>'
-        '<a href="https://github.com/sponsors/leycec">Feed the bear</a>! '
-        '<a href="https://www.etsy.com/ca/shop/BeadSpace9">Animals wearing jewelry</a>! '
-        '<i>What is even going on with this banner!?</i>'
-        '</p>'
-    ),
+    #FIXME: The "rst_prolog" approach above is currently preferred for some
+    #arcane reason we can no longer remember. *sigh*
+    # # Announcement banner defined as a string of arbitrary HTML, temporarily
+    # # displayed at the top of each page until the user begins scrolling.
+    # 'announcement': (
+    #     '<p>'
+    #     '<a href="https://github.com/sponsors/leycec">Feed the bear</a>! '
+    #     '<a href="https://www.etsy.com/ca/shop/BeadSpace9">Animals wearing jewelry</a>! '
+    #     '<i>What is even going on with this banner!?</i>'
+    #     '</p>'
+    # ),
 
     # List of one or more icon link descriptions. See also:
     # * Official theme-specific documentation for this setting:
@@ -576,16 +584,24 @@ html_theme_options = {
     #   https://fontawesome.com/icons?d=gallery&m=free
     #
     # Note that:
-    # * This theme requires long-form FontAwesome styles (e.g., "fa-brand",
+    # * This theme requires long-form FontAwesome styles (e.g., "fa-brands",
     #   "fa-solid") to be abbreviated to these three-letter abbreviations:
-    #   * "fa-brand" -> "fab".
+    #   * "fa-brands" -> "fab".
     #   * "fa-regular" -> "far".
     #   * "fa-solid" -> "fas".
     'icon_links': [
+        {
+            'name': 'Bluesky',
+            'url': URL_BLUESKY,
+            #FIXME: Preferable, but unavailable under the older FontAwesome
+            #dialect leveraged by this obsolete theme version. *sigh*
+            # 'icon': 'fab fa-bluesky',
+            'icon': 'fas fa-cloud',  # <-- whatevahs!
+        },
         {
             'name': 'GitHub',
             'url': URL_REPO,
-            'icon': 'fab fa-github-square',
+            'icon': 'fab fa-github',
         },
         {
             'name': 'PyPI',
@@ -595,7 +611,12 @@ html_theme_options = {
         {
             'name': 'Anaconda',
             'url': URL_CONDA,
-            'icon': 'far fa-circle',
+            #FIXME: Preferable, but unavailable under the older FontAwesome
+            #dialect leveraged by this obsolete theme version. *sigh*
+            # 'icon': 'fas fa-staff-snake',
+            #FIXME: Actually, it'd probably be preferable just to use the
+            #Unicode snake character, which is *ADORABLE*: 🐍
+            'icon': 'fas fa-circle',  # <-- whatevahs!
         },
         {
             'name': 'Libraries.io',
